#### What are the relevant issues?
<!---
Please prefix your pull request Title ↑↑↑ with the issue number too.
e.g. "feature/PY-DEV-2: Add additional flux capacitors"
-->
feature/PY-DEV-xxx

#### What does this PR do?
<!---
Please include a summary of the change. Please also include relevant motivation and context. List
any dependencies that are required for this change.
-->

#### Where should the reviewer start?
<!---
file_name.py
-->

#### Type of change
<!---
- [x] This is checked state.
-->
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Refactoring (non-breaking change which does not add functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as
expected)

#### Checklist:
<!---
Please delete options that are not relevant.
-->
- Is there any change in DynamoDB? (e.g. new column)
- Is there any change in configuration file? (e.g. new field)
- Is there any change that adds new Python dependencies which need to be added to requirements.txt?
- Is there any change that requires a documentation update?

#### Tests need to be added
<!---
file_name.py
-->
